.. tdl documentation master file, created by
   sphinx-quickstart on Fri Nov 25 12:49:46 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tdl's documentation!
===============================

**Current documentation is a work in progress.**

It will still be a while for the docs to be ported from the old epydoc format.

Until then you should be using the old docs found at:
https://pythonhosted.org/tdl/

Contents:

.. toctree::
   :maxdepth: 2

   api_ref


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

